购物车界面 - Bootstrap后台管理系统模版Ace下载
Description: 站长素材提供Bootstrap模版,Bootstrap教程,Bootstrap中文翻译等相关Bootstrap插件下载
Keywords: Bootstrap模版,Bootstrap模版下载,Bootstrap教程,Bootstrap中文

### Customer Invoice

Invoice: #121212
Date: 03/03/2013
Company Info

- Street, City
- Zip Code
- State, Country
- Phone: 111-111-111
- Paymant Info

Customer Info

- Street, City
- Zip Code
- State, Country
- Contact Info

# | Product | Description | Discount | Total
--- | --- | --- | --- | ---
1 | google.com | 1 year domain registration | --- | $10
2 | yahoo.com | 5 year domain registration | 5% | $45
3 | Hosting | 1 year basic hosting | 10% | $90
4 | Design | Theme customization | 50% | $250

#### Total amount : $395

Extra Information
Thank you for choosing Ace Company products. We believe you will be satisfied by our services.
Choose Skin
Fixed Navbar
Fixed Sidebar
Fixed Breadcrumbs
Right To Left (rtl)
Inside .container